==> estateplat-common-1.2.1-20170612.074700-27-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwJsydzrzxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/5/3
 * @description 权籍，建设用地自然幢信息视图
 */
@Table(name = "djsj_fw_jsydzrzxx")
public class DjsjFwJsydzrzxx {
    private String fw_jsydzrzxx_index;//主键
    private String fw_dcb_index;//逻辑幢主键
    private String lszd;//隶属宗地
    private String zrzh;//自然幢号
    private String gcjd;//工程进度
    private Double ghjzmj;//规划建筑面积
    private Double bzghmjbl;//本幢规划面积占比例
    private Double bzscmjbl;//本幢实测面积占比例
    private Double ycjzmj;//预测建筑面积
    private Double scjzmj;//实测建筑面积
    private String ybltddy;//已办理土地抵押
    private String yrwys;//已入网预售
    private String yblzjgcdy;//已办理在建工程抵押
    private String ycf;//已查封
    private String yblscdj;//已办理首次登记
    private String bz;//备注
    private String bgbh;//变更编号

    public String getFw_jsydzrzxx_index() {
        return fw_jsydzrzxx_index;
    }

    public void setFw_jsydzrzxx_index(String fw_jsydzrzxx_index) {
        this.fw_jsydzrzxx_index = fw_jsydzrzxx_index;
    }

    public String getFw_dcb_index() {
        return fw_dcb_index;
    }

    public void setFw_dcb_index(String fw_dcb_index) {
        this.fw_dcb_index = fw_dcb_index;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getGcjd() {
        return gcjd;
    }

    public void setGcjd(String gcjd) {
        this.gcjd = gcjd;
    }

    public Double getGhjzmj() {
        return ghjzmj;
    }

    public void setGhjzmj(Double ghjzmj) {
        this.ghjzmj = ghjzmj;
    }

    public Double getBzghmjbl() {
        return bzghmjbl;
    }

    public void setBzghmjbl(Double bzghmjbl) {
        this.bzghmjbl = bzghmjbl;
    }

    public Double getBzscmjbl() {
        return bzscmjbl;
    }

    public void setBzscmjbl(Double bzscmjbl) {
        this.bzscmjbl = bzscmjbl;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getYbltddy() {
        return ybltddy;
    }

    public void setYbltddy(String ybltddy) {
        this.ybltddy = ybltddy;
    }

    public String getYrwys() {
        return yrwys;
    }

    public void setYrwys(String yrwys) {
        this.yrwys = yrwys;
    }

    public String getYblzjgcdy() {
        return yblzjgcdy;
    }

    public void setYblzjgcdy(String yblzjgcdy) {
        this.yblzjgcdy = yblzjgcdy;
    }

    public String getYcf() {
        return ycf;
    }

    public void setYcf(String ycf) {
        this.ycf = ycf;
    }

    public String getYblscdj() {
        return yblscdj;
    }

    public void setYblscdj(String yblscdj) {
        this.yblscdj = yblscdj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBgbh() {
        return bgbh;
    }

    public void setBgbh(String bgbh) {
        this.bgbh = bgbh;
    }
}

==> estateplat-common-1.2.3-20180301.015717-35-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwJsydzrzxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/5/3
 * @description 权籍，建设用地自然幢信息视图
 */
@Table(name = "djsj_fw_jsydzrzxx")
public class DjsjFwJsydzrzxx {
    private String fwJsydzrzxxIndex;//主键
    private String fwDcbIndex;//逻辑幢主键
    private String lszd;//隶属宗地
    private String zrzh;//自然幢号
    private String gcjd;//工程进度
    private Double ghjzmj;//规划建筑面积
    private Double bzghmjbl;//本幢规划面积占比例
    private Double bzscmjbl;//本幢实测面积占比例
    private Double ycjzmj;//预测建筑面积
    private Double scjzmj;//实测建筑面积
    private String ybltddy;//已办理土地抵押
    private String yrwys;//已入网预售
    private String yblzjgcdy;//已办理在建工程抵押
    private String ycf;//已查封
    private String yblscdj;//已办理首次登记
    private String bz;//备注
    private String bgbh;//变更编号

    public String getFwJsydzrzxxIndex() {
        return fwJsydzrzxxIndex;
    }

    public void setFwJsydzrzxxIndex(String fwJsydzrzxxIndex) {
        this.fwJsydzrzxxIndex = fwJsydzrzxxIndex;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getGcjd() {
        return gcjd;
    }

    public void setGcjd(String gcjd) {
        this.gcjd = gcjd;
    }

    public Double getGhjzmj() {
        return ghjzmj;
    }

    public void setGhjzmj(Double ghjzmj) {
        this.ghjzmj = ghjzmj;
    }

    public Double getBzghmjbl() {
        return bzghmjbl;
    }

    public void setBzghmjbl(Double bzghmjbl) {
        this.bzghmjbl = bzghmjbl;
    }

    public Double getBzscmjbl() {
        return bzscmjbl;
    }

    public void setBzscmjbl(Double bzscmjbl) {
        this.bzscmjbl = bzscmjbl;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getYbltddy() {
        return ybltddy;
    }

    public void setYbltddy(String ybltddy) {
        this.ybltddy = ybltddy;
    }

    public String getYrwys() {
        return yrwys;
    }

    public void setYrwys(String yrwys) {
        this.yrwys = yrwys;
    }

    public String getYblzjgcdy() {
        return yblzjgcdy;
    }

    public void setYblzjgcdy(String yblzjgcdy) {
        this.yblzjgcdy = yblzjgcdy;
    }

    public String getYcf() {
        return ycf;
    }

    public void setYcf(String ycf) {
        this.ycf = ycf;
    }

    public String getYblscdj() {
        return yblscdj;
    }

    public void setYblscdj(String yblscdj) {
        this.yblscdj = yblscdj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBgbh() {
        return bgbh;
    }

    public void setBgbh(String bgbh) {
        this.bgbh = bgbh;
    }
}
